services

package
v0.0.0-...-887dc56 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 21, 2020 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Copyright © 2020 weapons97@gmail.com

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

var NotHelmFromContext = fmt.Errorf(`can't find helm client from context'`)

Functions

func HelmFromContext

func HelmFromContext(ctx context.Context) (adapter.Adapter, bool)

Types

type HelmApiService

type HelmApiService struct {
}

func (*HelmApiService) All

func (has *HelmApiService) All(ctx context.Context, lcr *protos.ListChartReq) (res *protos.SearchRes, e error)

All

func (*HelmApiService) CreateContext

func (has *HelmApiService) CreateContext(ctx context.Context, creq *protos.HelmContextReq) (hr *protos.HelmContextRes, e error)

CreateHelmContext

func (*HelmApiService) DeleteContext

func (has *HelmApiService) DeleteContext(ctx context.Context, dreq *protos.DeleteHelmContextReq) (*empty.Empty, error)

DeleteHelmContext

func (*HelmApiService) GetChart

func (has *HelmApiService) GetChart(ctx context.Context, gcr *protos.GetChartReq) (c *protos.Chart, e error)

GetChart 如果chart 里面含有非文本数据会返回错误

func (*HelmApiService) GetRelease

func (has *HelmApiService) GetRelease(ctx context.Context, grr *protos.ReleaseReq) (r *protos.Release, e error)

GetRelease 如果release 对应chart 里面含有非文本数据会返回错误

func (*HelmApiService) GetReleaseHistory

func (has *HelmApiService) GetReleaseHistory(ctx context.Context, rr *protos.ReleaseReq) (history *protos.ListReleaseRes, e error)

GetReleaseHistory

func (*HelmApiService) GetReleaseValues

func (has *HelmApiService) GetReleaseValues(ctx context.Context, grr *protos.ReleaseReq) (v *protos.Values, e error)

GetRelease 如果release 对应chart 里面含有非文本数据会返回错误

func (*HelmApiService) InstallRelease

func (has *HelmApiService) InstallRelease(ctx context.Context, ir *protos.InstallReq) (r *protos.Release, e error)

InstallCharts

func (*HelmApiService) ListRelease

func (has *HelmApiService) ListRelease(ctx context.Context, lr *protos.ListReleaseReq) (lres *protos.ListReleaseRes, e error)

GetRelease 如果release 对应chart 里面含有非文本数据会返回错误

func (*HelmApiService) RollbackRelease

func (has *HelmApiService) RollbackRelease(ctx context.Context, rr *protos.ReleaseRollbackReq) (emp *empty.Empty, e error)

RollbackRelease

func (*HelmApiService) Search

func (has *HelmApiService) Search(ctx context.Context, sr *protos.SearchReq) (res *protos.SearchRes, e error)

Search

func (*HelmApiService) UninstallRelease

func (has *HelmApiService) UninstallRelease(ctx context.Context, rr *protos.ReleaseReq) (emp *empty.Empty, e error)

UninstallRelease

func (*HelmApiService) UpdateRepo

func (has *HelmApiService) UpdateRepo(ctx context.Context, req *protos.UpdateRepoReq) (emp *empty.Empty, e error)

UpdateRepo

func (*HelmApiService) UpgradeRelease

func (has *HelmApiService) UpgradeRelease(ctx context.Context, ur *protos.UpgradeReq) (r *protos.Release, e error)

Upgrade

Jump to